## 命令行翻译工具

[![asciicast](https://asciinema.org/a/277253.svg)](https://asciinema.org/a/277253)


### API:
* Youdao
* Baidu

### Install

```bash
$ sudo python3 setup.py install
```

```bash
$ pip3 install cmd-fanyi
```

Changelog
--

* 2020-06-14
    1. 代码重构
    2. 添加控制台
    3. 修复百度翻译授权(支持cookie传入)
